/* adv16.c: Adv770 - copyright Mike Arnautov 2018. licensed under
 * GPL (version 3 or later) or the Modified BSD Licence, whichever
 * is asserted by the supplied LICENCE file.*/

#include "adv0.h"
#include "adv3.h"
int p8(void)
{
if (anyof(1009,924,-1))say(64,2004,0);
 if (loop) return(0);return 0;
}
