/* adv17.c: Adv770 - copyright Mike Arnautov 2018. licensed under
 * GPL (version 3 or later) or the Modified BSD Licence, whichever
 * is asserted by the supplied LICENCE file.*/

#include "adv0.h"
#include "adv3.h"
int p2()
{
#if ADVLIB
   rep = 0;
   if (nrep < 1) { if (p3() || loop) return 0; rep = 1; }
   if (nrep < 2) { if (p4() || loop) return 0; rep = 2; }
   if (nrep < 3) { if (p5() || loop) return 0; rep = 3; }
   if (nrep < 4) { if (p6() || loop) return 0; rep = 4; }
   if (nrep < 5) { if (p7() || loop) return 0; rep = 5; }
   if (nrep < 6) { if (p8() || loop) return 0; rep = 6; }
#else
   if (p3() || loop) return 0;
   if (p4() || loop) return 0;
   if (p5() || loop) return 0;
   if (p6() || loop) return 0;
   if (p7() || loop) return 0;
   if (p8() || loop) return 0;
#endif /* ADVLIB */
   return 1;
}
int p140()
{
   if (p141() || loop) return 0;
   if (p142() || loop) return 0;
   if (p143() || loop) return 0;
   if (p144() || loop) return 0;
   return 1;
}
int p228()
{
   if (p229() || loop) return 0;
   if (p230() || loop) return 0;
   return 1;
}
int p258()
{
   if (p259() || loop) return 0;
   if (p260() || loop) return 0;
   return 1;
}
int p261()
{
   if (p262() || loop) return 0;
   if (p263() || loop) return 0;
   if (p264() || loop) return 0;
   if (p265() || loop) return 0;
   if (p266() || loop) return 0;
   if (p267() || loop) return 0;
   return 1;
}
int p274()
{
   if (p275() || loop) return 0;
   if (p276() || loop) return 0;
   if (p277() || loop) return 0;
   if (p278() || loop) return 0;
   if (p279() || loop) return 0;
   if (p280() || loop) return 0;
   if (p281() || loop) return 0;
   if (p282() || loop) return 0;
   if (p283() || loop) return 0;
   if (p284() || loop) return 0;
   if (p285() || loop) return 0;
   if (p286() || loop) return 0;
   if (p287() || loop) return 0;
   if (p288() || loop) return 0;
   if (p289() || loop) return 0;
   if (p290() || loop) return 0;
   return 1;
}
int p301()
{
   if (p302() || loop) return 0;
   if (p303() || loop) return 0;
   return 1;
}
int p308()
{
   if (p309() || loop) return 0;
   if (p310() || loop) return 0;
   if (p311() || loop) return 0;
   if (p312() || loop) return 0;
   if (p313() || loop) return 0;
   if (p314() || loop) return 0;
   if (p315() || loop) return 0;
   if (p316() || loop) return 0;
   return 1;
}
int p317()
{
   if (p318() || loop) return 0;
   if (p319() || loop) return 0;
   return 1;
}
int p325()
{
   if (p326() || loop) return 0;
   if (p327() || loop) return 0;
   return 1;
}
int p365()
{
   if (p366() || loop) return 0;
   if (p367() || loop) return 0;
   if (p368() || loop) return 0;
   if (p369() || loop) return 0;
   if (p370() || loop) return 0;
   if (p371() || loop) return 0;
   return 1;
}
int p384()
{
   if (p385() || loop) return 0;
   if (p386() || loop) return 0;
   if (p387() || loop) return 0;
   if (p388() || loop) return 0;
   return 1;
}
int p638()
{
   if (p639() || loop) return 0;
   if (p640() || loop) return 0;
   if (p641() || loop) return 0;
   if (p642() || loop) return 0;
   if (p643() || loop) return 0;
   if (p644() || loop) return 0;
   if (p645() || loop) return 0;
   if (p646() || loop) return 0;
   if (p647() || loop) return 0;
   if (p648() || loop) return 0;
   if (p649() || loop) return 0;
   if (p650() || loop) return 0;
   return 1;
}
int p733()
{
   if (p734() || loop) return 0;
   if (p735() || loop) return 0;
   if (p736() || loop) return 0;
   if (p737() || loop) return 0;
   if (p738() || loop) return 0;
   return 1;
}
int p835()
{
   if (p836() || loop) return 0;
   if (p837() || loop) return 0;
   if (p838() || loop) return 0;
   if (p839() || loop) return 0;
   if (p840() || loop) return 0;
   if (p841() || loop) return 0;
   if (p842() || loop) return 0;
   if (p843() || loop) return 0;
   if (p844() || loop) return 0;
   return 1;
}
int p893()
{
   if (p894() || loop) return 0;
   if (p895() || loop) return 0;
   if (p896() || loop) return 0;
   return 1;
}
int p905()
{
   if (p906() || loop) return 0;
   if (p907() || loop) return 0;
   if (p908() || loop) return 0;
   return 1;
}
int p0(void)
{return 0;}
