/* adv3.h: Adv770 - copyright Mike Arnautov 2018. licensed under
 * GPL (version 3 or later) or the Modified BSD Licence, whichever
 * is asserted by the supplied LICENCE file.*/

extern void fake(int x, int y);
extern int p0(void);
extern int p1(void);
extern int p2(void);
extern int p3(void);
extern int p4(void);
extern int p5(void);
extern int p6(void);
extern int p7(void);
extern int p8(void);
extern int p9(void);
extern int p10(void);
extern int p11(void);
extern int p12(void);
extern int p13(void);
extern int p14(void);
extern int p15(void);
extern int p16(void);
extern int p17(void);
extern int p18(void);
extern int p19(void);
extern int p20(int,int);
extern int p21(int,int);
extern int p22(int,int);
extern int p23(void);
extern int p24(void);
extern int p25(void);
extern int p26(void);
extern int p27(void);
extern int p28(void);
extern int p29(void);
extern int p30(void);
extern int p31(void);
extern int p32(void);
extern int p33(void);
extern int p34(void);
extern int p35(void);
extern int p36(void);
extern int p37(void);
extern int p38(void);
extern int p39(void);
extern int p40(void);
extern int p41(void);
extern int p42(void);
extern int p43(void);
extern int p44(void);
extern int p45(void);
extern int p46(void);
extern int p47(void);
extern int p48(void);
extern int p49(void);
extern int p50(void);
extern int p51(void);
extern int p52(void);
extern int p53(void);
extern int p54(void);
extern int p55(void);
extern int p56(void);
extern int p57(void);
extern int p58(void);
extern int p59(void);
extern int p60(void);
extern int p61(void);
extern int p62(void);
extern int p63(void);
extern int p64(void);
extern int p65(void);
extern int p66(void);
extern int p67(void);
extern int p68(void);
extern int p69(void);
extern int p70(void);
extern int p71(void);
extern int p72(void);
extern int p73(void);
extern int p74(void);
extern int p75(void);
extern int p76(void);
extern int p77(void);
extern int p78(void);
extern int p79(void);
extern int p80(void);
extern int p81(void);
extern int p82(void);
extern int p83(void);
extern int p84(void);
extern int p85(void);
extern int p86(void);
extern int p87(void);
extern int p88(void);
extern int p89(void);
extern int p90(void);
extern int p91(void);
extern int p92(void);
extern int p93(void);
extern int p94(void);
extern int p95(void);
extern int p96(void);
extern int p97(void);
extern int p98(void);
extern int p99(void);
extern int p100(void);
extern int p101(void);
extern int p102(void);
extern int p103(void);
extern int p104(void);
extern int p105(void);
extern int p106(void);
extern int p107(void);
extern int p108(void);
extern int p109(void);
extern int p110(void);
extern int p111(void);
extern int p112(void);
extern int p113(void);
extern int p114(void);
extern int p115(void);
extern int p116(void);
extern int p117(void);
extern int p118(void);
extern int p119(void);
extern int p120(void);
extern int p121(void);
extern int p122(void);
extern int p123(void);
extern int p124(void);
extern int p125(void);
extern int p126(int,int);
extern int p127(void);
extern int p128(void);
extern int p129(void);
extern int p130(void);
extern int p131(void);
extern int p132(void);
extern int p133(void);
extern int p134(void);
extern int p135(void);
extern int p136(void);
extern int p137(void);
extern int p138(void);
extern int p139(void);
extern int p140(void);
extern int p141(void);
extern int p142(void);
extern int p143(void);
extern int p144(void);
extern int p145(void);
extern int p146(void);
extern int p147(void);
extern int p148(void);
extern int p149(void);
extern int p150(void);
extern int p151(int,int);
extern int p152(void);
extern int p153(void);
extern int p154(void);
extern int p155(void);
extern int p156(void);
extern int p157(void);
extern int p158(void);
extern int p159(void);
extern int p160(void);
extern int p161(void);
extern int p162(void);
extern int p163(void);
extern int p164(void);
extern int p165(void);
extern int p166(void);
extern int p167(void);
extern int p168(void);
extern int p169(void);
extern int p170(void);
extern int p171(void);
extern int p172(void);
extern int p173(void);
extern int p174(void);
extern int p175(void);
extern int p176(void);
extern int p177(void);
extern int p178(void);
extern int p179(void);
extern int p180(void);
extern int p181(void);
extern int p182(void);
extern int p183(void);
extern int p184(int,int);
extern int p185(void);
extern int p186(void);
extern int p187(void);
extern int p188(void);
extern int p189(void);
extern int p190(void);
extern int p191(void);
extern int p192(void);
extern int p193(void);
extern int p194(void);
extern int p195(void);
extern int p196(void);
extern int p197(void);
extern int p198(void);
extern int p199(void);
extern int p200(void);
extern int p201(void);
extern int p202(void);
extern int p203(void);
extern int p204(void);
extern int p205(void);
extern int p206(void);
extern int p207(void);
extern int p208(void);
extern int p209(void);
extern int p210(void);
extern int p211(void);
extern int p212(void);
extern int p213(void);
extern int p214(void);
extern int p215(void);
extern int p216(void);
extern int p217(void);
extern int p218(void);
extern int p219(void);
extern int p220(void);
extern int p221(void);
extern int p222(void);
extern int p223(int,int);
extern int p224(void);
extern int p225(void);
extern int p226(void);
extern int p227(void);
extern int p228(void);
extern int p229(void);
extern int p230(void);
extern int p231(void);
extern int p232(void);
extern int p233(int,int);
extern int p234(void);
extern int p235(void);
extern int p236(void);
extern int p237(void);
extern int p238(void);
extern int p239(void);
extern int p240(int,int);
extern int p241(void);
extern int p242(void);
extern int p243(void);
extern int p244(void);
extern int p245(void);
extern int p246(int,int);
extern int p247(void);
extern int p248(void);
extern int p249(void);
extern int p250(void);
extern int p251(void);
extern int p252(void);
extern int p253(void);
extern int p254(void);
extern int p255(void);
extern int p256(void);
extern int p257(void);
extern int p258(void);
extern int p259(void);
extern int p260(void);
extern int p261(void);
extern int p262(void);
extern int p263(void);
extern int p264(void);
extern int p265(void);
extern int p266(void);
extern int p267(void);
extern int p268(void);
extern int p269(void);
extern int p270(void);
extern int p271(void);
extern int p272(void);
extern int p273(void);
extern int p274(void);
extern int p275(void);
extern int p276(void);
extern int p277(void);
extern int p278(void);
extern int p279(void);
extern int p280(void);
extern int p281(void);
extern int p282(void);
extern int p283(void);
extern int p284(void);
extern int p285(void);
extern int p286(void);
extern int p287(void);
extern int p288(void);
extern int p289(void);
extern int p290(void);
extern int p291(void);
extern int p292(void);
extern int p293(void);
extern int p294(void);
extern int p295(void);
extern int p296(void);
extern int p297(int,int,int,int);
extern int p298(void);
extern int p299(void);
extern int p300(void);
extern int p301(void);
extern int p302(void);
extern int p303(void);
extern int p304(void);
extern int p305(void);
extern int p306(void);
extern int p307(void);
extern int p308(void);
extern int p309(void);
extern int p310(void);
extern int p311(void);
extern int p312(void);
extern int p313(void);
extern int p314(void);
extern int p315(void);
extern int p316(void);
extern int p317(void);
extern int p318(void);
extern int p319(void);
extern int p320(int,int);
extern int p321(int,int);
extern int p322(void);
extern int p323(void);
extern int p324(void);
extern int p325(void);
extern int p326(void);
extern int p327(void);
extern int p328(void);
extern int p329(int,int,int,int,int,int,int,int);
extern int p330(void);
extern int p331(void);
extern int p332(void);
extern int p333(void);
extern int p334(void);
extern int p335(void);
extern int p336(void);
extern int p337(void);
extern int p338(void);
extern int p339(void);
extern int p340(void);
extern int p341(void);
extern int p342(void);
extern int p343(void);
extern int p344(void);
extern int p345(void);
extern int p346(void);
extern int p347(void);
extern int p348(void);
extern int p349(void);
extern int p350(void);
extern int p351(void);
extern int p352(void);
extern int p353(void);
extern int p354(void);
extern int p355(void);
extern int p356(void);
extern int p357(void);
extern int p358(void);
extern int p359(void);
extern int p360(void);
extern int p361(void);
extern int p362(void);
extern int p363(void);
extern int p364(void);
extern int p365(void);
extern int p366(void);
extern int p367(void);
extern int p368(void);
extern int p369(void);
extern int p370(void);
extern int p371(void);
extern int p372(void);
extern int p373(void);
extern int p374(void);
extern int p375(void);
extern int p376(void);
extern int p377(void);
extern int p378(void);
extern int p379(void);
extern int p380(void);
extern int p381(void);
extern int p382(void);
extern int p383(int,int);
extern int p384(void);
extern int p385(void);
extern int p386(void);
extern int p387(void);
extern int p388(void);
extern int p389(void);
extern int p390(void);
extern int p391(void);
extern int p392(void);
extern int p393(void);
extern int p394(void);
extern int p395(void);
extern int p396(void);
extern int p397(void);
extern int p398(void);
extern int p399(void);
extern int p400(void);
extern int p401(void);
extern int p402(void);
extern int p403(void);
extern int p404(void);
extern int p405(void);
extern int p406(void);
extern int p407(void);
extern int p408(void);
extern int p409(void);
extern int p410(int,int);
extern int p411(void);
extern int p412(void);
extern int p413(void);
extern int p414(void);
extern int p415(void);
extern int p416(void);
extern int p417(void);
extern int p418(void);
extern int p419(void);
extern int p420(void);
extern int p421(void);
extern int p422(void);
extern int p423(void);
extern int p424(void);
extern int p425(void);
extern int p426(void);
extern int p427(void);
extern int p428(void);
extern int p429(void);
extern int p430(void);
extern int p431(void);
extern int p432(void);
extern int p433(void);
extern int p434(void);
extern int p435(void);
extern int p436(void);
extern int p437(void);
extern int p438(void);
extern int p439(void);
extern int p440(void);
extern int p441(void);
extern int p442(void);
extern int p443(void);
extern int p444(void);
extern int p445(void);
extern int p446(void);
extern int p447(void);
extern int p448(void);
extern int p449(void);
extern int p450(void);
extern int p451(void);
extern int p452(void);
extern int p453(void);
extern int p454(void);
extern int p455(void);
extern int p456(void);
extern int p457(void);
extern int p458(void);
extern int p459(void);
extern int p460(void);
extern int p461(void);
extern int p462(void);
extern int p463(void);
extern int p464(void);
extern int p465(void);
extern int p466(void);
extern int p467(int,int);
extern int p468(void);
extern int p469(void);
extern int p470(void);
extern int p471(void);
extern int p472(void);
extern int p473(void);
extern int p474(void);
extern int p475(void);
extern int p476(void);
extern int p477(void);
extern int p478(void);
extern int p479(void);
extern int p480(void);
extern int p481(void);
extern int p482(void);
extern int p483(void);
extern int p484(void);
extern int p485(void);
extern int p486(void);
extern int p487(void);
extern int p488(void);
extern int p489(void);
extern int p490(void);
extern int p491(void);
extern int p492(void);
extern int p493(void);
extern int p494(void);
extern int p495(void);
extern int p496(void);
extern int p497(void);
extern int p498(void);
extern int p499(void);
extern int p500(void);
extern int p501(void);
extern int p502(void);
extern int p503(void);
extern int p504(void);
extern int p505(void);
extern int p506(void);
extern int p507(void);
extern int p508(void);
extern int p509(void);
extern int p510(int,int,int,int);
extern int p511(void);
extern int p512(void);
extern int p513(void);
extern int p514(void);
extern int p515(void);
extern int p516(void);
extern int p517(int,int);
extern int p518(void);
extern int p519(void);
extern int p520(void);
extern int p521(void);
extern int p522(void);
extern int p523(void);
extern int p524(void);
extern int p525(void);
extern int p526(void);
extern int p527(void);
extern int p528(void);
extern int p529(void);
extern int p530(void);
extern int p531(void);
extern int p532(void);
extern int p533(void);
extern int p534(int,int);
extern int p535(void);
extern int p536(void);
extern int p537(void);
extern int p538(void);
extern int p539(void);
extern int p540(void);
extern int p541(void);
extern int p542(void);
extern int p543(void);
extern int p544(void);
extern int p545(void);
extern int p546(void);
extern int p547(void);
extern int p548(void);
extern int p549(void);
extern int p550(int,int,int,int);
extern int p551(void);
extern int p552(void);
extern int p553(void);
extern int p554(void);
extern int p555(void);
extern int p556(void);
extern int p557(void);
extern int p558(void);
extern int p559(void);
extern int p560(void);
extern int p561(void);
extern int p562(void);
extern int p563(void);
extern int p564(void);
extern int p565(void);
extern int p566(void);
extern int p567(void);
extern int p568(void);
extern int p569(void);
extern int p570(void);
extern int p571(void);
extern int p572(void);
extern int p573(void);
extern int p574(void);
extern int p575(void);
extern int p576(void);
extern int p577(void);
extern int p578(void);
extern int p579(void);
extern int p580(void);
extern int p581(void);
extern int p582(void);
extern int p583(void);
extern int p584(void);
extern int p585(void);
extern int p586(void);
extern int p587(void);
extern int p588(void);
extern int p589(void);
extern int p590(void);
extern int p591(void);
extern int p592(void);
extern int p593(void);
extern int p594(void);
extern int p595(void);
extern int p596(void);
extern int p597(void);
extern int p598(void);
extern int p599(void);
extern int p600(void);
extern int p601(void);
extern int p602(void);
extern int p603(void);
extern int p604(void);
extern int p605(void);
extern int p606(void);
extern int p607(void);
extern int p608(void);
extern int p609(void);
extern int p610(void);
extern int p611(void);
extern int p612(void);
extern int p613(void);
extern int p614(void);
extern int p615(void);
extern int p616(void);
extern int p617(void);
extern int p618(void);
extern int p619(void);
extern int p620(void);
extern int p621(void);
extern int p622(void);
extern int p623(void);
extern int p624(void);
extern int p625(int,int);
extern int p626(int,int,int,int);
extern int p627(void);
extern int p628(void);
extern int p629(void);
extern int p630(void);
extern int p631(void);
extern int p632(void);
extern int p633(void);
extern int p634(void);
extern int p635(void);
extern int p636(void);
extern int p637(void);
extern int p638(void);
extern int p639(void);
extern int p640(void);
extern int p641(void);
extern int p642(void);
extern int p643(void);
extern int p644(void);
extern int p645(void);
extern int p646(void);
extern int p647(void);
extern int p648(void);
extern int p649(void);
extern int p650(void);
extern int p651(void);
extern int p652(void);
extern int p653(void);
extern int p654(void);
extern int p655(void);
extern int p656(void);
extern int p657(void);
extern int p658(int,int,int,int);
extern int p659(void);
extern int p660(void);
extern int p661(void);
extern int p662(void);
extern int p663(void);
extern int p664(void);
extern int p665(void);
extern int p666(void);
extern int p667(void);
extern int p668(void);
extern int p669(void);
extern int p670(void);
extern int p671(int,int);
extern int p672(void);
extern int p673(void);
extern int p674(void);
extern int p675(void);
extern int p676(void);
extern int p677(void);
extern int p678(void);
extern int p679(int,int);
extern int p680(void);
extern int p681(void);
extern int p682(void);
extern int p683(void);
extern int p684(void);
extern int p685(void);
extern int p686(void);
extern int p687(void);
extern int p688(void);
extern int p689(void);
extern int p690(void);
extern int p691(void);
extern int p692(void);
extern int p693(void);
extern int p694(void);
extern int p695(void);
extern int p696(void);
extern int p697(void);
extern int p698(void);
extern int p699(void);
extern int p700(void);
extern int p701(void);
extern int p702(void);
extern int p703(void);
extern int p704(void);
extern int p705(void);
extern int p706(void);
extern int p707(void);
extern int p708(void);
extern int p709(void);
extern int p710(void);
extern int p711(void);
extern int p712(void);
extern int p713(void);
extern int p714(void);
extern int p715(void);
extern int p716(void);
extern int p717(void);
extern int p718(void);
extern int p719(void);
extern int p720(void);
extern int p721(void);
extern int p722(void);
extern int p723(void);
extern int p724(int,int);
extern int p725(void);
extern int p726(void);
extern int p727(void);
extern int p728(void);
extern int p729(void);
extern int p730(void);
extern int p731(void);
extern int p732(void);
extern int p733(void);
extern int p734(void);
extern int p735(void);
extern int p736(void);
extern int p737(void);
extern int p738(void);
extern int p739(void);
extern int p740(void);
extern int p741(void);
extern int p742(void);
extern int p743(void);
extern int p744(void);
extern int p745(void);
extern int p746(void);
extern int p747(void);
extern int p748(void);
extern int p749(void);
extern int p750(void);
extern int p751(void);
extern int p752(void);
extern int p753(void);
extern int p754(void);
extern int p755(void);
extern int p756(void);
extern int p757(void);
extern int p758(void);
extern int p759(void);
extern int p760(void);
extern int p761(void);
extern int p762(void);
extern int p763(void);
extern int p764(void);
extern int p765(void);
extern int p766(void);
extern int p767(void);
extern int p768(void);
extern int p769(void);
extern int p770(void);
extern int p771(void);
extern int p772(void);
extern int p773(void);
extern int p774(void);
extern int p775(void);
extern int p776(void);
extern int p777(void);
extern int p778(void);
extern int p779(void);
extern int p780(void);
extern int p781(void);
extern int p782(void);
extern int p783(void);
extern int p784(void);
extern int p785(void);
extern int p786(void);
extern int p787(void);
extern int p788(void);
extern int p789(void);
extern int p790(void);
extern int p791(void);
extern int p792(void);
extern int p793(void);
extern int p794(void);
extern int p795(void);
extern int p796(void);
extern int p797(void);
extern int p798(void);
extern int p799(void);
extern int p800(void);
extern int p801(void);
extern int p802(void);
extern int p803(void);
extern int p804(void);
extern int p805(void);
extern int p806(void);
extern int p807(int,int);
extern int p808(void);
extern int p809(void);
extern int p810(void);
extern int p811(void);
extern int p812(void);
extern int p813(void);
extern int p814(void);
extern int p815(void);
extern int p816(int,int,int,int);
extern int p817(void);
extern int p818(void);
extern int p819(void);
extern int p820(void);
extern int p821(void);
extern int p822(void);
extern int p823(void);
extern int p824(void);
extern int p825(void);
extern int p826(void);
extern int p827(void);
extern int p828(void);
extern int p829(void);
extern int p830(int,int);
extern int p831(void);
extern int p832(void);
extern int p833(void);
extern int p834(void);
extern int p835(void);
extern int p836(void);
extern int p837(void);
extern int p838(void);
extern int p839(void);
extern int p840(void);
extern int p841(void);
extern int p842(void);
extern int p843(void);
extern int p844(void);
extern int p845(void);
extern int p846(void);
extern int p847(void);
extern int p848(void);
extern int p849(void);
extern int p850(void);
extern int p851(int,int);
extern int p852(void);
extern int p853(void);
extern int p854(void);
extern int p855(void);
extern int p856(void);
extern int p857(void);
extern int p858(void);
extern int p859(void);
extern int p860(void);
extern int p861(void);
extern int p862(void);
extern int p863(void);
extern int p864(void);
extern int p865(void);
extern int p866(void);
extern int p867(int,int,int,int);
extern int p868(void);
extern int p869(void);
extern int p870(void);
extern int p871(void);
extern int p872(void);
extern int p873(void);
extern int p874(void);
extern int p875(void);
extern int p876(void);
extern int p877(void);
extern int p878(void);
extern int p879(void);
extern int p880(void);
extern int p881(void);
extern int p882(void);
extern int p883(int,int);
extern int p884(void);
extern int p885(void);
extern int p886(void);
extern int p887(void);
extern int p888(void);
extern int p889(void);
extern int p890(void);
extern int p891(void);
extern int p892(void);
extern int p893(void);
extern int p894(void);
extern int p895(void);
extern int p896(void);
extern int p897(void);
extern int p898(void);
extern int p899(void);
extern int p900(void);
extern int p901(int,int,int,int,int,int);
extern int p902(void);
extern int p903(void);
extern int p904(void);
extern int p905(void);
extern int p906(void);
extern int p907(void);
extern int p908(void);
extern int p909(void);
extern int p910(void);
extern int p911(void);
extern int p912(void);
extern int p913(void);
extern int p914(void);
extern int p915(void);
extern int p916(void);
extern int p917(void);
extern int p918(void);
extern int p919(void);
extern int p920(void);
extern int p921(void);
extern int p922(void);
extern int p923(void);
extern int p924(void);
extern int p925(void);
extern int p926(void);
extern int p927(void);
extern int p928(void);
extern int p929(void);
extern int p930(void);
extern int p931(void);
extern int p932(void);
extern int p933(void);
extern int p934(void);
extern int p935(void);
extern int p936(void);
extern int p937(void);
extern int p938(void);
extern int p939(void);
extern int p940(void);
extern int p941(void);
extern int p942(void);
extern int p943(void);
extern int p944(void);
extern int p945(void);
